# if __name__ == "__main__":
#     source_dsn = {"host": "192.168.161.94", "user": "cy", "password": "cy"}
#     target_dsn = {"host": "192.168.161.94", "user": "cy", "password": "cy"}
#     MysqlTableCompare(source_dsn, target_dsn, "merchant_center_ouku_v1", "v3_wh_to_whg", "merchant_center_ouku_v1", "v3_wh_to_whg", 1, 200).run()

# from mysql_compare import MysqlTableCompare

# source_dsn = {"host": "172.23.8.58", "user": "ghost", "password": "54448hotINBOX"}
# target_dsn = {"host": "10.242.23.60", "user": "ghost", "password": "54448hotINBOX"}
# MysqlTableCompare(
#     source_dsn,
#     target_dsn,
#     "merchant_center_ouku_v1",
#     "__delete_mc_products_cms_20220415",
#     "merchant_center_ouku_v1",
#     "__delete_mc_products_cms_20220415",
#     1,
#     10000,
# ).run()
